==> eiffelstudio-18.01.10.1424.tar: F_code/C39/co1942.c <==
/*
 * Code for class COLLECTION [CHARACTER_8]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co1942.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {COLLECTION}.fill */
void F489_6101 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_CHARACTER_8 tc1;
	RTCDT;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("fill", 488, Current, 1, 1, 6193);
	RTGC;
	RTHOOK(1);
	loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5151[Dtype(arg1)-442])(RTCW(arg1));
	RTHOOK(2);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R5255[Dtype(loc1)-481])(RTCW(loc1));
	for (;;) {
		RTHOOK(3);
		tb1 = '\01';
		if (!(EIF_BOOLEAN) !(FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5282[dtype-562])(Current)) {
			tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5254[Dtype(loc1)-457])(RTCW(loc1));
			tb1 = tb2;
		}
		if (tb1) break;
		RTHOOK(4);
		tc1 = *(EIF_CHARACTER_8 *)(eif_optimize_return = 1, (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5253[Dtype(loc1)-481])(RTCW(loc1)));
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[dtype-562])(Current, (EIF_REFERENCE) &tc1);
		RTHOOK(5);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5268[Dtype(loc1)-481])(RTCW(loc1));
	}
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {COLLECTION}.prune_all */
void F489_6103 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1)
{
	GTCX
	RTEX;
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("prune_all", 488, Current, 0, 1, 6194);
	RTGC;
	for (;;) {
		RTHOOK(1);
		if ((EIF_BOOLEAN) !(FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R5144[dtype-442])(Current, (EIF_REFERENCE) &arg1)) break;
		RTHOOK(2);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5288[dtype-562])(Current, (EIF_REFERENCE) &arg1);
	}
	RTHOOK(3);
	RTLE;
	RTEE;
}

void EIF_Minit1942 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.07.10.1981.tar: F_code/C39/co1942.c <==
/*
 * Code for class COLLECTION [CHARACTER_32]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "co1942.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {COLLECTION}.fill */
void F490_6101 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTCDT;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("fill", 489, Current, 1, 1, 6196);
	RTGC;
	RTHOOK(1);
	loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5151[Dtype(arg1)-442])(RTCW(arg1));
	RTHOOK(2);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R5255[Dtype(loc1)-481])(RTCW(loc1));
	for (;;) {
		RTHOOK(3);
		tb1 = '\01';
		if (!(EIF_BOOLEAN) !(FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5282[dtype-562])(Current)) {
			tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5254[Dtype(loc1)-457])(RTCW(loc1));
			tb1 = tb2;
		}
		if (tb1) break;
		RTHOOK(4);
		tw1 = F1088_9935(RTCW(loc1));
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5286[dtype-562])(Current, (EIF_REFERENCE) &tw1);
		RTHOOK(5);
		F1088_9963(RTCW(loc1));
	}
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {COLLECTION}.prune_all */
void F490_6103 (EIF_REFERENCE Current, EIF_CHARACTER_32 arg1)
{
	GTCX
	RTEX;
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("prune_all", 489, Current, 0, 1, 6197);
	RTGC;
	for (;;) {
		RTHOOK(1);
		if ((EIF_BOOLEAN) !(FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R5144[dtype-442])(Current, (EIF_REFERENCE) &arg1)) break;
		RTHOOK(2);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5288[dtype-562])(Current, (EIF_REFERENCE) &arg1);
	}
	RTHOOK(3);
	RTLE;
	RTEE;
}

void EIF_Minit1942 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
